@@ -1,4 +1,4 @@
-# @(#)Ident: CPANTesting.pm 2013-07-30 12:50 pjf ;
+# @(#)Ident: CPANTesting.pm 2013-08-08 13:11 pjf ;
 
 package CPANTesting;
 
@@ -11,7 +11,7 @@ use Sys::Hostname; my $host = lc hostname; my $osname = lc $^O;
 sub is_testing { !! ($ENV{AUTOMATED_TESTING} || $ENV{PERL_CR_SMOKER_CURRENT}
                  || ($ENV{PERL5OPT} || q()) =~ m{ CPAN-Reporter }mx) }
 
-sub should_abort {
+sub should_abort { # Only if the smoker cannot run the toolchain
    is_testing() or return 0;
 
    $host eq q(xphvmfred) and return
@@ -20,14 +20,13 @@ sub should_abort {
 }
 
 sub test_exceptions {
-   my $p = shift; my $perl_ver = $p->{requires}->{perl};
+   my $p = shift; my $perl_ver = $p->{_min_perl_ver} || $p->{requires}->{perl};
 
-   is_testing()           or  return 0;
-   $] < $perl_ver         and return "TESTS: Perl minimum ${perl_ver}";
-   $p->{stop_tests}       and return 'TESTS: CPAN Testing stopped in Build.PL';
-   $osname eq q(mirbsd)   and return 'TESTS: Mirbsd OS unsupported';
-   $host eq q(training02) and return
-      "TESTS: 5f6e9967-6e40-1014-8340-fe22e79c0688";
+   is_testing()         or  return 0;
+   $] < $perl_ver       and return "TESTS: Perl minimum ${perl_ver}";
+   $p->{stop_tests}     and return 'TESTS: CPAN Testing stopped in Build.PL';
+   $osname eq 'mirbsd'  and return 'TESTS: Mirbsd OS unsupported';
+   $osname eq 'mswin32' and return 'tests: RT#87575';
    return 0;
 }
 
